@@ -1,14 +1,7 @@
-#! perl
+#!/usr/bin/env perl
 
-BEGIN { $ENV{CATALYST_ENGINE} ||= 'CGI' }
-
-use strict;
-use warnings;
-use FindBin;
-use lib "$FindBin::Bin/../lib";
-use Tapper::Reports::Web;
-
-Tapper::Reports::Web->run;
+use Catalyst::ScriptRunner;
+Catalyst::ScriptRunner->run('Tapper::Reports::Web', 'CGI');
 
 1;
 
@@ -30,6 +23,8 @@ Catalyst Contributors, see Catalyst.pm
 
 =head1 COPYRIGHT
 
-This program is released under the following license: freebsd
+This library is free software. You can redistribute it and/or modify
+it under the same terms as Perl itself.
 
 =cut
+
